import { world } from "@minecraft/server";
import Database from "../Database.js";

/** @type {{ [tag: string]: number }} */
const REWARD_TAGS = {
  royalty: 100_000_000,
  ultra: 20_000_000,
  omega: 2_000_000,
  vipplus: 50_000,
  vip: 10_000,
  player: 1_000
};

/**
 * Format milliseconds to HH:MM:SS
 */
function formatTime(ms) {
  const totalSeconds = Math.floor(ms / 1000);
  const hours = Math.floor(totalSeconds / 3600).toString().padStart(2, "0");
  const minutes = Math.floor((totalSeconds % 3600) / 60).toString().padStart(2, "0");
  const seconds = (totalSeconds % 60).toString().padStart(2, "0");
  return `${hours}:${minutes}:${seconds}`;
}

/**
 * Main daily reward function
 * @param {import("@minecraft/server").Player} player
 */
export default function DailyReward(player) {
  const tag = Object.keys(REWARD_TAGS).find(t => player.hasTag(t));
  if (!tag) {
    player.sendMessage("§cYou do not have any VIP rank to claim a daily reward.");
    return;
  }

  const now = new Date();
  const todayStr = now.toISOString().split("T")[0]; // e.g., "2025-05-15"
  const lastClaimDate = Database.get("dailyRewardDate", player);

  if (lastClaimDate === todayStr) {
    // Already claimed today
    const tomorrow = new Date(now);
    tomorrow.setHours(24, 0, 0, 0);
    const timeLeft = formatTime(tomorrow - now);
    player.sendMessage(`§cYou already claimed your reward today.\n§7Try again in §e${timeLeft}`);
    return;
  }

  const reward = REWARD_TAGS[tag];
  player.runCommand(`scoreboard players add "${player.name}" money ${reward}`);
  player.sendMessage(`§aYou received §e$${reward.toLocaleString()} §afor your §l${tag.toUpperCase()}§r§a rank!`);

  Database.set("dailyRewardDate", todayStr, player);
}
