import { world } from "@minecraft/server";
import { ModalFormData } from "@minecraft/server-ui";

/**
 * @param {Player} sender 
 */
export default async function SendMoney(sender) {
    const players = world.getPlayers().filter(p => p !== sender);
    if (players.length === 0) return sender.sendMessage("§cThere are no other players online.");

    const form = new ModalFormData()
        .title("§aSend Money")
        .dropdown("§7Select a player to send money to:", players.map(p => p.name))
        .textField("§7Enter amount to send", "e.g. 100");

    const { canceled, formValues } = await form.show(sender);
    if (canceled) return;

    const [targetIndex, amountText] = formValues;
    const amount = parseInt(amountText);
    const receiver = players[targetIndex];

    if (isNaN(amount) || amount <= 0) {
        sender.sendMessage("§cInvalid amount.");
        return;
    }

    const senderScore = getMoney(sender);
    if (senderScore < amount) {
        sender.sendMessage("§cYou do not have enough money to send.");
        return;
    }

    addMoney(sender, -amount);
    addMoney(receiver, amount);

    sender.sendMessage(`§aYou sent §6$${amount} §ato §e${receiver.name}`);
    receiver.sendMessage(`§aYou received §6$${amount} §afrom §e${sender.name}`);
}

function getMoney(player) {
    try {
        return world.scoreboard.getObjective("money").getScore(player.scoreboardIdentity);
    } catch {
        return 0;
    }
}

function addMoney(player, amount) {
    try {
        world.scoreboard.getObjective("money").setScore(player.scoreboardIdentity, getMoney(player) + amount);
    } catch {
        // silently fail
    }
}
