import { world } from "@minecraft/server";
import { ModalFormData } from "@minecraft/server-ui";

/**
 * Allows an admin to send a fake message as another player
 * @param {import("@minecraft/server").Player} player 
 */
export default async function Sudo(player) {
    const players = world.getPlayers().filter(p => p !== player);
    if (players.length === 0) {
        player.sendMessage("§cNo other players online.");
        return;
    }

    const form = new ModalFormData()
        .title("§cSudo Message")
        .dropdown("§aSelect a player", players.map(p => p.name))
        .textField("§bMessage", "Enter the message here");

    const { canceled, formValues } = await form.show(player);
    if (canceled) return;

    const targetPlayer = players[formValues[0]];
    const message = formValues[1];

    const tags = targetPlayer.getTags();
    const rankTag = tags.find(t => t.startsWith("rank:")) || "rank:§aPlayer";
    const colorTag = tags.find(t => t.startsWith("color:")) || "color:§7";
    const chatColorTag = tags.find(t => t.startsWith("chatcolor:")) || "chatcolor:§f";

    const rank = rankTag.split(":")[1];
    const nameColor = colorTag.split(":")[1];
    const chatColor = chatColorTag.split(":")[1];

    const tellraw = `tellraw @a {"rawtext":[{"text":"§7[${rank}§r§7] ${nameColor}${targetPlayer.name} §r§7>> ${chatColor}${message}§r"}]}`;

    try {
        player.runCommand(tellraw);
        player.sendMessage("§aSudo message sent.");
    } catch (e) {
        player.sendMessage("§cFailed to send message.");
        console.warn(`[SUDO ERROR] ${e}`);
    }
}
